[![codecov](https://codecov.io/gh/sbacchio/tuneit/branch/master/graph/badge.svg)](https://codecov.io/gh/sbacchio/tuneit)

# Tuneit

## A Python tool for tuning, benchmarking and crosschecking calculations

Tuneit is a generic purpose tool for optimizing and crosschecking calculations.
Its usage is simple and with few changes one can turn few lines of Python code
into a tunable and dynamical calculation.
